.. _source:


.. raw:: html

     <br><br>

.. title:: Source


**GENOCIDE**

.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    sbn.command	  commands
    sbn.console	  terminal
    sbn.errored	  errors
    sbn.listens	  bus
    sbn.message	  events
    sbn.modules	  plugins
    sbn.objects	  clean namespace
    sbn.reactor   reacting
    sbn.repeats   repeating
    sbn.runtime   running 
    sbn.threads   threading
    sbn.utility   utilities


.. raw:: html

     <br>


**MODULES**


.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    sbn.modules.bsc	basic commands
    sbn.modules.err	show errors
    sbn.modules.flt     list bots
    sbn.modules.irc	internet relay chat
    sbn.modules.log	log text
    sbn.modules.mdl	genocide model
    sbn.modules.mod	list modules
    sbn.modules.req	request
    sbn.modules.rss	rich site syndicate
    sbn.modules.shp	shopping list
    sbn.modules.sts     status
    sbn.modules.tdo	todo list
    sbn.modules.thr	list threads
    sbn.modules.udp	udp to irc relay
    sbn.modules.wsd 	wisdom
